"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Angle:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AngleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Angle.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ANGLE_UNSPECIFIED: _Angle.ValueType  # 0
    ANGLE_0: _Angle.ValueType  # 1
    ANGLE_90: _Angle.ValueType  # 2
    ANGLE_180: _Angle.ValueType  # 3
    ANGLE_270: _Angle.ValueType  # 4

class Angle(_Angle, metaclass=_AngleEnumTypeWrapper): ...

ANGLE_UNSPECIFIED: Angle.ValueType  # 0
ANGLE_0: Angle.ValueType  # 1
ANGLE_90: Angle.ValueType  # 2
ANGLE_180: Angle.ValueType  # 3
ANGLE_270: Angle.ValueType  # 4
global___Angle = Angle

class _LayoutType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LayoutTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LayoutType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LAYOUT_TYPE_UNSPECIFIED: _LayoutType.ValueType  # 0
    LAYOUT_TYPE_UNKNOWN: _LayoutType.ValueType  # 1
    LAYOUT_TYPE_TEXT: _LayoutType.ValueType  # 2
    LAYOUT_TYPE_HEADER: _LayoutType.ValueType  # 3
    LAYOUT_TYPE_SECTION_HEADER: _LayoutType.ValueType  # 4
    LAYOUT_TYPE_FOOTER: _LayoutType.ValueType  # 5
    LAYOUT_TYPE_FOOTNOTE: _LayoutType.ValueType  # 6
    LAYOUT_TYPE_PICTURE: _LayoutType.ValueType  # 7
    LAYOUT_TYPE_CAPTION: _LayoutType.ValueType  # 8
    LAYOUT_TYPE_TITLE: _LayoutType.ValueType  # 9
    LAYOUT_TYPE_LIST: _LayoutType.ValueType  # 10

class LayoutType(_LayoutType, metaclass=_LayoutTypeEnumTypeWrapper): ...

LAYOUT_TYPE_UNSPECIFIED: LayoutType.ValueType  # 0
LAYOUT_TYPE_UNKNOWN: LayoutType.ValueType  # 1
LAYOUT_TYPE_TEXT: LayoutType.ValueType  # 2
LAYOUT_TYPE_HEADER: LayoutType.ValueType  # 3
LAYOUT_TYPE_SECTION_HEADER: LayoutType.ValueType  # 4
LAYOUT_TYPE_FOOTER: LayoutType.ValueType  # 5
LAYOUT_TYPE_FOOTNOTE: LayoutType.ValueType  # 6
LAYOUT_TYPE_PICTURE: LayoutType.ValueType  # 7
LAYOUT_TYPE_CAPTION: LayoutType.ValueType  # 8
LAYOUT_TYPE_TITLE: LayoutType.ValueType  # 9
LAYOUT_TYPE_LIST: LayoutType.ValueType  # 10
global___LayoutType = LayoutType

@typing.final
class Polygon(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERTICES_FIELD_NUMBER: builtins.int
    @property
    def vertices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Vertex]:
        """The bounding polygon vertices."""

    def __init__(
        self,
        *,
        vertices: collections.abc.Iterable[global___Vertex] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vertices", b"vertices"]) -> None: ...

global___Polygon = Polygon

@typing.final
class Vertex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    X_FIELD_NUMBER: builtins.int
    Y_FIELD_NUMBER: builtins.int
    x: builtins.int
    """X coordinate in pixels."""
    y: builtins.int
    """Y coordinate in pixels."""
    def __init__(
        self,
        *,
        x: builtins.int = ...,
        y: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["x", b"x", "y", b"y"]) -> None: ...

global___Vertex = Vertex

@typing.final
class TextAnnotation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    BLOCKS_FIELD_NUMBER: builtins.int
    ENTITIES_FIELD_NUMBER: builtins.int
    TABLES_FIELD_NUMBER: builtins.int
    FULL_TEXT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    MARKDOWN_FIELD_NUMBER: builtins.int
    PICTURES_FIELD_NUMBER: builtins.int
    width: builtins.int
    """Page width in pixels."""
    height: builtins.int
    """Page height in pixels."""
    full_text: builtins.str
    """Full text recognized from image."""
    rotate: global___Angle.ValueType
    """Angle of image rotation."""
    markdown: builtins.str
    """Full markdown (without pictures inside) from image. Available only in markdown and math-markdown models."""
    @property
    def blocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Block]:
        """Recognized text blocks in this page."""

    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Entity]:
        """Recognized entities."""

    @property
    def tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Table]: ...
    @property
    def pictures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Picture]:
        """List of pictures locations from image."""

    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        blocks: collections.abc.Iterable[global___Block] | None = ...,
        entities: collections.abc.Iterable[global___Entity] | None = ...,
        tables: collections.abc.Iterable[global___Table] | None = ...,
        full_text: builtins.str = ...,
        rotate: global___Angle.ValueType = ...,
        markdown: builtins.str = ...,
        pictures: collections.abc.Iterable[global___Picture] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["blocks", b"blocks", "entities", b"entities", "full_text", b"full_text", "height", b"height", "markdown", b"markdown", "pictures", b"pictures", "rotate", b"rotate", "tables", b"tables", "width", b"width"]) -> None: ...

global___TextAnnotation = TextAnnotation

@typing.final
class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Entity name."""
    text: builtins.str
    """Recognized entity text."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "text", b"text"]) -> None: ...

global___Entity = Entity

@typing.final
class Block(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DetectedLanguage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LANGUAGE_CODE_FIELD_NUMBER: builtins.int
        language_code: builtins.str
        """Detected language code."""
        def __init__(
            self,
            *,
            language_code: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["language_code", b"language_code"]) -> None: ...

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    LANGUAGES_FIELD_NUMBER: builtins.int
    TEXT_SEGMENTS_FIELD_NUMBER: builtins.int
    LAYOUT_TYPE_FIELD_NUMBER: builtins.int
    layout_type: global___LayoutType.ValueType
    """Block layout type."""
    @property
    def bounding_box(self) -> global___Polygon:
        """Area on the page where the text block is located."""

    @property
    def lines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Line]:
        """Recognized lines in this block."""

    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Block.DetectedLanguage]:
        """A list of detected languages"""

    @property
    def text_segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TextSegments]:
        """Block position from full_text string."""

    def __init__(
        self,
        *,
        bounding_box: global___Polygon | None = ...,
        lines: collections.abc.Iterable[global___Line] | None = ...,
        languages: collections.abc.Iterable[global___Block.DetectedLanguage] | None = ...,
        text_segments: collections.abc.Iterable[global___TextSegments] | None = ...,
        layout_type: global___LayoutType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "languages", b"languages", "layout_type", b"layout_type", "lines", b"lines", "text_segments", b"text_segments"]) -> None: ...

global___Block = Block

@typing.final
class Line(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    TEXT_SEGMENTS_FIELD_NUMBER: builtins.int
    ORIENTATION_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Recognized text."""
    orientation: global___Angle.ValueType
    """Angle of line rotation."""
    @property
    def bounding_box(self) -> global___Polygon:
        """Area on the page where the line is located."""

    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Word]:
        """Recognized words."""

    @property
    def text_segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TextSegments]:
        """Line position from full_text string."""

    def __init__(
        self,
        *,
        bounding_box: global___Polygon | None = ...,
        text: builtins.str = ...,
        words: collections.abc.Iterable[global___Word] | None = ...,
        text_segments: collections.abc.Iterable[global___TextSegments] | None = ...,
        orientation: global___Angle.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "orientation", b"orientation", "text", b"text", "text_segments", b"text_segments", "words", b"words"]) -> None: ...

global___Line = Line

@typing.final
class Word(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    ENTITY_INDEX_FIELD_NUMBER: builtins.int
    TEXT_SEGMENTS_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Recognized word value."""
    entity_index: builtins.int
    """ID of the recognized word in entities array."""
    @property
    def bounding_box(self) -> global___Polygon:
        """Area on the page where the word is located."""

    @property
    def text_segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TextSegments]:
        """Word position from full_text string."""

    def __init__(
        self,
        *,
        bounding_box: global___Polygon | None = ...,
        text: builtins.str = ...,
        entity_index: builtins.int = ...,
        text_segments: collections.abc.Iterable[global___TextSegments] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "entity_index", b"entity_index", "text", b"text", "text_segments", b"text_segments"]) -> None: ...

global___Word = Word

@typing.final
class TextSegments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_INDEX_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    start_index: builtins.int
    """Start character position from full_text string."""
    length: builtins.int
    """Text segment length."""
    def __init__(
        self,
        *,
        start_index: builtins.int = ...,
        length: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["length", b"length", "start_index", b"start_index"]) -> None: ...

global___TextSegments = TextSegments

@typing.final
class Table(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    ROW_COUNT_FIELD_NUMBER: builtins.int
    COLUMN_COUNT_FIELD_NUMBER: builtins.int
    CELLS_FIELD_NUMBER: builtins.int
    row_count: builtins.int
    """Number of rows in table."""
    column_count: builtins.int
    """Number of columns in table."""
    @property
    def bounding_box(self) -> global___Polygon:
        """Area on the page where the table is located."""

    @property
    def cells(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableCell]:
        """Table cells."""

    def __init__(
        self,
        *,
        bounding_box: global___Polygon | None = ...,
        row_count: builtins.int = ...,
        column_count: builtins.int = ...,
        cells: collections.abc.Iterable[global___TableCell] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "cells", b"cells", "column_count", b"column_count", "row_count", b"row_count"]) -> None: ...

global___Table = Table

@typing.final
class TableCell(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    ROW_INDEX_FIELD_NUMBER: builtins.int
    COLUMN_INDEX_FIELD_NUMBER: builtins.int
    COLUMN_SPAN_FIELD_NUMBER: builtins.int
    ROW_SPAN_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_SEGMENTS_FIELD_NUMBER: builtins.int
    row_index: builtins.int
    """Row index."""
    column_index: builtins.int
    """Column index."""
    column_span: builtins.int
    """Column span."""
    row_span: builtins.int
    """Row span."""
    text: builtins.str
    """Text in cell."""
    @property
    def bounding_box(self) -> global___Polygon:
        """Area on the page where the table cell is located."""

    @property
    def text_segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TextSegments]:
        """Table cell position from full_text string."""

    def __init__(
        self,
        *,
        bounding_box: global___Polygon | None = ...,
        row_index: builtins.int = ...,
        column_index: builtins.int = ...,
        column_span: builtins.int = ...,
        row_span: builtins.int = ...,
        text: builtins.str = ...,
        text_segments: collections.abc.Iterable[global___TextSegments] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "column_index", b"column_index", "column_span", b"column_span", "row_index", b"row_index", "row_span", b"row_span", "text", b"text", "text_segments", b"text_segments"]) -> None: ...

global___TableCell = TableCell

@typing.final
class Picture(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    score: builtins.float
    """Confidence score of picture location."""
    @property
    def bounding_box(self) -> global___Polygon:
        """Area on the page where the picture is located."""

    def __init__(
        self,
        *,
        bounding_box: global___Polygon | None = ...,
        score: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "score", b"score"]) -> None: ...

global___Picture = Picture



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.datatransfer.v1.transfer_pb2
import yandex.cloud.datatransfer.v1.transfer_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class TransferServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.CreateTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a transfer in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.UpdateTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified transfer."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.DeleteTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified transfer."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.ListTransfersRequest,
        yandex.cloud.datatransfer.v1.transfer_service_pb2.ListTransfersResponse,
    ]
    """Lists transfers in the specified folder."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.GetTransferRequest,
        yandex.cloud.datatransfer.v1.transfer_pb2.Transfer,
    ]
    """Returns the specified transfer.

    To get the list of all available transfers, make a [List] request.
    """

    Deactivate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.DeactivateTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deactivates the specified transfer.

    To get the list of all available transfers, make a [List] request.
    """

    Activate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.ActivateTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activates the specified transfer.

    To get the list of all available transfers, make a [List] request.
    """

class TransferServiceAsyncStub:
    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.CreateTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a transfer in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.UpdateTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified transfer."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.DeleteTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified transfer."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.ListTransfersRequest,
        yandex.cloud.datatransfer.v1.transfer_service_pb2.ListTransfersResponse,
    ]
    """Lists transfers in the specified folder."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.GetTransferRequest,
        yandex.cloud.datatransfer.v1.transfer_pb2.Transfer,
    ]
    """Returns the specified transfer.

    To get the list of all available transfers, make a [List] request.
    """

    Deactivate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.DeactivateTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deactivates the specified transfer.

    To get the list of all available transfers, make a [List] request.
    """

    Activate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.transfer_service_pb2.ActivateTransferRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activates the specified transfer.

    To get the list of all available transfers, make a [List] request.
    """

class TransferServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.datatransfer.v1.transfer_service_pb2.CreateTransferRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a transfer in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.datatransfer.v1.transfer_service_pb2.UpdateTransferRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified transfer."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.datatransfer.v1.transfer_service_pb2.DeleteTransferRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified transfer."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.datatransfer.v1.transfer_service_pb2.ListTransfersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datatransfer.v1.transfer_service_pb2.ListTransfersResponse, collections.abc.Awaitable[yandex.cloud.datatransfer.v1.transfer_service_pb2.ListTransfersResponse]]:
        """Lists transfers in the specified folder."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.datatransfer.v1.transfer_service_pb2.GetTransferRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datatransfer.v1.transfer_pb2.Transfer, collections.abc.Awaitable[yandex.cloud.datatransfer.v1.transfer_pb2.Transfer]]:
        """Returns the specified transfer.

        To get the list of all available transfers, make a [List] request.
        """

    @abc.abstractmethod
    def Deactivate(
        self,
        request: yandex.cloud.datatransfer.v1.transfer_service_pb2.DeactivateTransferRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deactivates the specified transfer.

        To get the list of all available transfers, make a [List] request.
        """

    @abc.abstractmethod
    def Activate(
        self,
        request: yandex.cloud.datatransfer.v1.transfer_service_pb2.ActivateTransferRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Activates the specified transfer.

        To get the list of all available transfers, make a [List] request.
        """

def add_TransferServiceServicer_to_server(servicer: TransferServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/assistants/v1/threads/thread.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/assistants/v1/threads/thread.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.assistants.v1 import common_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_common__pb2
from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/ai/assistants/v1/threads/thread.proto\x12%yandex.cloud.ai.assistants.v1.threads\x1a*yandex/cloud/ai/assistants/v1/common.proto\x1a#yandex/cloud/ai/common/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x98\x04\n\x06Thread\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12!\n\x19\x64\x65\x66\x61ult_message_author_id\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x11\x65xpiration_config\x18\n \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12.\n\nexpires_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x06labels\x18\x0c \x03(\x0b\x32\x39.yandex.cloud.ai.assistants.v1.threads.Thread.LabelsEntry\x12\x32\n\x05tools\x18\r \x03(\x0b\x32#.yandex.cloud.ai.assistants.v1.Tool\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42~\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threadsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.threads.thread_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threads'
  _globals['_THREAD_LABELSENTRY']._loaded_options = None
  _globals['_THREAD_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_THREAD']._serialized_start=208
  _globals['_THREAD']._serialized_end=744
  _globals['_THREAD_LABELSENTRY']._serialized_start=699
  _globals['_THREAD_LABELSENTRY']._serialized_end=744
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/connectionmanager/v1/common.proto\x12!yandex.cloud.connectionmanager.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x80\x01\n\tTLSParams\x12*\n\x08\x64isabled\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12;\n\x03tls\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSConfigH\x00\x42\n\n\x08tls_mode\"#\n\tTLSConfig\x12\x16\n\x0e\x63\x61_certificate\x18\x01 \x01(\t\"\xa6\x01\n\x08Password\x12\x0b\n\x03raw\x18\x01 \x01(\t\x12\x61\n\x1bpassword_generation_options\x18\x03 \x01(\x0b\x32<.yandex.cloud.connectionmanager.v1.PasswordGenerationOptions\x12\x1c\n\x12lockbox_secret_key\x18\x02 \x01(\tH\x00\x42\x0c\n\nsecret_key\"\xbe\x01\n\x19PasswordGenerationOptions\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\t\x12r\n#lockbox_password_generation_options\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.connectionmanager.v1.LockboxPasswordGenerationOptionsH\x00\x42\x1d\n\x1bpassword_generation_options\"\xcf\x02\n LockboxPasswordGenerationOptions\x12\x0e\n\x06length\x18\x02 \x01(\x03\x12\x35\n\x11include_uppercase\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11include_lowercase\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0einclude_digits\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13include_punctuation\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1c\n\x14included_punctuation\x18\x07 \x01(\t\x12\x1c\n\x14\x65xcluded_punctuation\x18\x08 \x01(\tJ\x04\x08\x01\x10\x02\"_\n\x10UserPasswordAuth\x12\x0c\n\x04user\x18\x01 \x01(\t\x12=\n\x08password\x18\x02 \x01(\x0b\x32+.yandex.cloud.connectionmanager.v1.PasswordB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_TLSPARAMS']._serialized_start=147
  _globals['_TLSPARAMS']._serialized_end=275
  _globals['_TLSCONFIG']._serialized_start=277
  _globals['_TLSCONFIG']._serialized_end=312
  _globals['_PASSWORD']._serialized_start=315
  _globals['_PASSWORD']._serialized_end=481
  _globals['_PASSWORDGENERATIONOPTIONS']._serialized_start=484
  _globals['_PASSWORDGENERATIONOPTIONS']._serialized_end=674
  _globals['_LOCKBOXPASSWORDGENERATIONOPTIONS']._serialized_start=677
  _globals['_LOCKBOXPASSWORDGENERATIONOPTIONS']._serialized_end=1012
  _globals['_USERPASSWORDAUTH']._serialized_start=1014
  _globals['_USERPASSWORDAUTH']._serialized_end=1109
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/operationlog/v1/operation_log.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/operationlog/v1/operation_log.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/operationlog/v1/operation_log.proto\x12 yandex.cloud.mdb.operationlog.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"Z\n\nHostEntity\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12.\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa0\x01\n\rClusterEntity\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12.\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x05hosts\x18\x04 \x03(\x0b\x32,.yandex.cloud.mdb.operationlog.v1.HostEntity\"Q\n\x0cOperationLog\x12\x41\n\x08\x65ntities\x18\x01 \x03(\x0b\x32/.yandex.cloud.mdb.operationlog.v1.ClusterEntityBy\n$yandex.cloud.api.mdb.operationlog.v1ZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/operationlog/v1;operationlogb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.operationlog.v1.operation_log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$yandex.cloud.api.mdb.operationlog.v1ZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/operationlog/v1;operationlog'
  _globals['_HOSTENTITY']._serialized_start=123
  _globals['_HOSTENTITY']._serialized_end=213
  _globals['_CLUSTERENTITY']._serialized_start=216
  _globals['_CLUSTERENTITY']._serialized_end=376
  _globals['_OPERATIONLOG']._serialized_start=378
  _globals['_OPERATIONLOG']._serialized_end=459
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.baremetal.v1alpha.dhcp_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PublicSubnetType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PublicSubnetTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PublicSubnetType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PUBLIC_SUBNET_TYPE_UNSPECIFIED: _PublicSubnetType.ValueType  # 0
    """Unspecified public subnet type."""
    DEDICATED: _PublicSubnetType.ValueType  # 1
    """Dedicated public subnet."""
    EPHEMERAL: _PublicSubnetType.ValueType  # 2
    """Ephemeral public subnet."""

class PublicSubnetType(_PublicSubnetType, metaclass=_PublicSubnetTypeEnumTypeWrapper):
    """Type of the public subnet."""

PUBLIC_SUBNET_TYPE_UNSPECIFIED: PublicSubnetType.ValueType  # 0
"""Unspecified public subnet type."""
DEDICATED: PublicSubnetType.ValueType  # 1
"""Dedicated public subnet."""
EPHEMERAL: PublicSubnetType.ValueType  # 2
"""Ephemeral public subnet."""
global___PublicSubnetType = PublicSubnetType

@typing.final
class PublicSubnet(google.protobuf.message.Message):
    """A PublicSubnet resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    HARDWARE_POOL_IDS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    CIDR_FIELD_NUMBER: builtins.int
    DHCP_OPTIONS_FIELD_NUMBER: builtins.int
    GATEWAY_IP_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the public subnet."""
    cloud_id: builtins.str
    """ID of the cloud that the public subnet belongs to."""
    folder_id: builtins.str
    """ID of the folder that the public subnet belongs to."""
    name: builtins.str
    """Name of the public subnet.
    The name is unique within the folder.
    """
    description: builtins.str
    """Optional description of the public subnet."""
    zone_id: builtins.str
    """ID of the availability zone where the server resides."""
    type: global___PublicSubnetType.ValueType
    """Type of the public subnet (static or ephemeral)."""
    prefix_length: builtins.int
    """Prefix length of the public subnet CIDR block."""
    cidr: builtins.str
    """CIDR block for the public subnet."""
    gateway_ip: builtins.str
    """Gateway IP address for the public subnet."""
    @property
    def hardware_pool_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of the hardware pool that the public subnet belongs to."""

    @property
    def dhcp_options(self) -> yandex.cloud.baremetal.v1alpha.dhcp_pb2.DhcpOptions:
        """DHCP options for the public subnet."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        zone_id: builtins.str = ...,
        hardware_pool_ids: collections.abc.Iterable[builtins.str] | None = ...,
        type: global___PublicSubnetType.ValueType = ...,
        prefix_length: builtins.int = ...,
        cidr: builtins.str = ...,
        dhcp_options: yandex.cloud.baremetal.v1alpha.dhcp_pb2.DhcpOptions | None = ...,
        gateway_ip: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "dhcp_options", b"dhcp_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cidr", b"cidr", "cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "dhcp_options", b"dhcp_options", "folder_id", b"folder_id", "gateway_ip", b"gateway_ip", "hardware_pool_ids", b"hardware_pool_ids", "id", b"id", "labels", b"labels", "name", b"name", "prefix_length", b"prefix_length", "type", b"type", "zone_id", b"zone_id"]) -> None: ...

global___PublicSubnet = PublicSubnet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.video.v1.episode_pb2
import yandex.cloud.video.v1.manifest_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetEpisodeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode to retrieve."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___GetEpisodeRequest = GetEpisodeRequest

@typing.final
class ListEpisodesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream containing the episodes to list."""
    line_id: builtins.str
    """ID of the stream line containing the episodes to list."""
    page_size: builtins.int
    """The maximum number of episodes to return per page."""
    page_token: builtins.str
    """Page token for retrieving the next page of results.
    This token is obtained from the next_page_token field in the previous ListEpisodesResponse.
    """
    order_by: builtins.str
    """Specifies the ordering of results.
    Format is "<field> <order>" (e.g., "createdAt desc").
    Default: "id asc".
    Supported fields: ["id", "createdAt", "updatedAt"].
    Both snake_case and camelCase field names are supported.
    """
    filter: builtins.str
    """Filter expression to narrow down the list of returned episodes.
    Expressions consist of terms connected by logical operators.
    Values containing spaces or quotes must be enclosed in quotes (`'` or `"`)
    with inner quotes being backslash-escaped.

    Supported logical operators: ["AND", "OR"].
    Supported comparison operators: ["=", "!=", ":"] where ":" enables substring matching.
    Parentheses can be used to group logical expressions.

    Example: `title:'highlight' AND id='episode-1'`

    Filterable fields: ["id", "title"].
    Both snake_case and camelCase field names are supported.
    """
    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        line_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["line_id", b"line_id", "parent_id", b"parent_id", "stream_id", b"stream_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "line_id", b"line_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token", "parent_id", b"parent_id", "stream_id", b"stream_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["stream_id", "line_id"] | None: ...

global___ListEpisodesRequest = ListEpisodesRequest

@typing.final
class ListEpisodesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of results.
    Empty if there are no more results available.
    """
    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.episode_pb2.Episode]:
        """List of episodes matching the request criteria.
        May be empty if no episodes match the criteria or if the parent resource has no episodes.
        """

    def __init__(
        self,
        *,
        episodes: collections.abc.Iterable[yandex.cloud.video.v1.episode_pb2.Episode] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episodes", b"episodes", "next_page_token", b"next_page_token"]) -> None: ...

global___ListEpisodesResponse = ListEpisodesResponse

@typing.final
class BatchGetEpisodesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    EPISODE_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the episodes to retrieve."""
    @property
    def episode_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of episode IDs to retrieve."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        episode_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "episode_ids", b"episode_ids"]) -> None: ...

global___BatchGetEpisodesRequest = BatchGetEpisodesRequest

@typing.final
class BatchGetEpisodesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODES_FIELD_NUMBER: builtins.int
    @property
    def episodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.episode_pb2.Episode]:
        """List of episodes matching the requested IDs."""

    def __init__(
        self,
        *,
        episodes: collections.abc.Iterable[yandex.cloud.video.v1.episode_pb2.Episode] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episodes", b"episodes"]) -> None: ...

global___BatchGetEpisodesResponse = BatchGetEpisodesResponse

@typing.final
class CreateEpisodeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    DVR_SECONDS_FIELD_NUMBER: builtins.int
    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream."""
    line_id: builtins.str
    """ID of the line."""
    title: builtins.str
    """Episode title."""
    description: builtins.str
    """Episode description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    dvr_seconds: builtins.int
    """Enables episode DVR mode.
    Determines how many last seconds of the stream are available.

    Possible values:
     * `0`: infinite dvr size, the full length of the stream allowed to display
     * `>0`: size of dvr window in seconds, the minimum value is 30s
    """
    style_preset_id: builtins.str
    """ID of the style preset."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Episode start time."""

    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Episode finish time."""

    @property
    def public_access(self) -> global___EpisodePublicAccessParams:
        """Episode is publicly available."""

    @property
    def sign_url_access(self) -> global___EpisodeSignURLAccessParams:
        """Access to the episode is restricted by temporarily signed links."""

    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        line_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        dvr_seconds: builtins.int = ...,
        style_preset_id: builtins.str = ...,
        public_access: global___EpisodePublicAccessParams | None = ...,
        sign_url_access: global___EpisodeSignURLAccessParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "finish_time", b"finish_time", "line_id", b"line_id", "parent_id", b"parent_id", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time", "stream_id", b"stream_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "description", b"description", "dvr_seconds", b"dvr_seconds", "finish_time", b"finish_time", "line_id", b"line_id", "parent_id", b"parent_id", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time", "stream_id", b"stream_id", "style_preset_id", b"style_preset_id", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["stream_id", "line_id"] | None: ...

global___CreateEpisodeRequest = CreateEpisodeRequest

@typing.final
class EpisodePublicAccessParams(google.protobuf.message.Message):
    """Parameters for episode public access rights."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EpisodePublicAccessParams = EpisodePublicAccessParams

@typing.final
class EpisodeSignURLAccessParams(google.protobuf.message.Message):
    """Parameters for episode access restrictions based on temporary signed links."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___EpisodeSignURLAccessParams = EpisodeSignURLAccessParams

@typing.final
class CreateEpisodeMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode being created."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___CreateEpisodeMetadata = CreateEpisodeMetadata

@typing.final
class UpdateEpisodeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    FINISH_TIME_FIELD_NUMBER: builtins.int
    DVR_SECONDS_FIELD_NUMBER: builtins.int
    STYLE_PRESET_ID_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode."""
    title: builtins.str
    """Episode title."""
    description: builtins.str
    """Episode description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    dvr_seconds: builtins.int
    """Enables episode DVR mode.
    Determines how many last seconds of the stream are available.

    Possible values:
     * `0`: infinite dvr size, the full length of the stream allowed to display
     * `>0`: size of dvr window in seconds, the minimum value is 30s
    """
    style_preset_id: builtins.str
    """New ID of the style preset to be applied to the episode player."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the episode should be updated.
        Only fields specified in this mask will be modified;
        all other fields will retain their current values.
        This allows for partial updates.
        """

    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Episode start time."""

    @property
    def finish_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Episode finish time."""

    @property
    def public_access(self) -> global___EpisodePublicAccessParams:
        """Episode is publicly available."""

    @property
    def sign_url_access(self) -> global___EpisodeSignURLAccessParams:
        """Access to the episode is restricted by temporarily signed links."""

    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finish_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        dvr_seconds: builtins.int = ...,
        style_preset_id: builtins.str = ...,
        public_access: global___EpisodePublicAccessParams | None = ...,
        sign_url_access: global___EpisodeSignURLAccessParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "field_mask", b"field_mask", "finish_time", b"finish_time", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "description", b"description", "dvr_seconds", b"dvr_seconds", "episode_id", b"episode_id", "field_mask", b"field_mask", "finish_time", b"finish_time", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "start_time", b"start_time", "style_preset_id", b"style_preset_id", "thumbnail_id", b"thumbnail_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...

global___UpdateEpisodeRequest = UpdateEpisodeRequest

@typing.final
class UpdateEpisodeMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode being updated."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___UpdateEpisodeMetadata = UpdateEpisodeMetadata

@typing.final
class DeleteEpisodeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode to delete."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___DeleteEpisodeRequest = DeleteEpisodeRequest

@typing.final
class DeleteEpisodeMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode being deleted.
    This identifier can be used to track the episode deletion operation.
    """
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___DeleteEpisodeMetadata = DeleteEpisodeMetadata

@typing.final
class BatchDeleteEpisodesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STREAM_ID_FIELD_NUMBER: builtins.int
    LINE_ID_FIELD_NUMBER: builtins.int
    EPISODE_IDS_FIELD_NUMBER: builtins.int
    stream_id: builtins.str
    """ID of the stream containing the episodes to delete."""
    line_id: builtins.str
    """ID of the stream line containing the episodes to delete."""
    @property
    def episode_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of episode IDs to delete.
        All episodes must exist and be linked to the specified parent resource.
        """

    def __init__(
        self,
        *,
        stream_id: builtins.str = ...,
        line_id: builtins.str = ...,
        episode_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["id", b"id", "line_id", b"line_id", "stream_id", b"stream_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["episode_ids", b"episode_ids", "id", b"id", "line_id", b"line_id", "stream_id", b"stream_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["stream_id", "line_id"] | None: ...

global___BatchDeleteEpisodesRequest = BatchDeleteEpisodesRequest

@typing.final
class BatchDeleteEpisodesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_IDS_FIELD_NUMBER: builtins.int
    @property
    def episode_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of episode IDs being deleted.
        This list can be used to track which episodes are included
        in the batch deletion operation.
        """

    def __init__(
        self,
        *,
        episode_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_ids", b"episode_ids"]) -> None: ...

global___BatchDeleteEpisodesMetadata = BatchDeleteEpisodesMetadata

@typing.final
class PerformEpisodeActionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    UNPUBLISH_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode on which to perform the action."""
    @property
    def publish(self) -> global___PublishEpisodeAction:
        """Publish the episode, making it available for watching.
        Changes the episode's visibility status to PUBLISHED.
        """

    @property
    def unpublish(self) -> global___UnpublishEpisodeAction:
        """Unpublish the episode, making it unavailable for watching.
        Changes the episode's visibility status to UNPUBLISHED.
        """

    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
        publish: global___PublishEpisodeAction | None = ...,
        unpublish: global___UnpublishEpisodeAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "unpublish", b"unpublish"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "episode_id", b"episode_id", "publish", b"publish", "unpublish", b"unpublish"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["publish", "unpublish"] | None: ...

global___PerformEpisodeActionRequest = PerformEpisodeActionRequest

@typing.final
class PublishEpisodeAction(google.protobuf.message.Message):
    """Parameters for the publish action."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishEpisodeAction = PublishEpisodeAction

@typing.final
class UnpublishEpisodeAction(google.protobuf.message.Message):
    """Parameters for the unpublish action."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UnpublishEpisodeAction = UnpublishEpisodeAction

@typing.final
class PerformEpisodeActionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode on which the action is being performed.
    This identifier can be used to track the action operation
    and to verify that the action is being applied to the correct episode.
    """
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___PerformEpisodeActionMetadata = PerformEpisodeActionMetadata

@typing.final
class GetEpisodePlayerURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    SIGNED_URL_EXPIRATION_DURATION_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode for which to generate a player URL."""
    @property
    def params(self) -> global___EpisodePlayerParams:
        """Optional player parameters to customize the playback experience.
        These parameters control initial player state such as mute, autoplay, and visibility of interface controls.
        """

    @property
    def signed_url_expiration_duration(self) -> google.protobuf.duration_pb2.Duration:
        """For episodes with signed URL access, specifies how long the generated URL will be valid.
        If not provided, a default expiration duration will be used.
        """

    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
        params: global___EpisodePlayerParams | None = ...,
        signed_url_expiration_duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id", "params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration"]) -> None: ...

global___GetEpisodePlayerURLRequest = GetEpisodePlayerURLRequest

@typing.final
class EpisodePlayerParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTE_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    mute: builtins.bool
    """If true, the player will start with audio muted.
    Users can unmute the audio manually after playback starts.
    """
    autoplay: builtins.bool
    """If true, the episode will start playing automatically when the player loads.
    This may be subject to browser autoplay policies that restrict autoplay with sound.
    """
    hidden: builtins.bool
    """If true, the player interface controls will be hidden initially.
    Users can typically reveal the controls by moving the mouse over the player.
    """
    def __init__(
        self,
        *,
        mute: builtins.bool = ...,
        autoplay: builtins.bool = ...,
        hidden: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["autoplay", b"autoplay", "hidden", b"hidden", "mute", b"mute"]) -> None: ...

global___EpisodePlayerParams = EpisodePlayerParams

@typing.final
class GetEpisodePlayerURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_URL_FIELD_NUMBER: builtins.int
    HTML_FIELD_NUMBER: builtins.int
    player_url: builtins.str
    """Direct URL to the episode player.
    This URL can be used to access the episode in a web browser
    or shared with users who have appropriate permissions.
    """
    html: builtins.str
    """HTML embed code in iframe format that can be inserted into web pages.
    This code allows the episode to be embedded directly in third-party websites.
    """
    def __init__(
        self,
        *,
        player_url: builtins.str = ...,
        html: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["html", b"html", "player_url", b"player_url"]) -> None: ...

global___GetEpisodePlayerURLResponse = GetEpisodePlayerURLResponse

@typing.final
class GetEpisodeManifestsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPISODE_ID_FIELD_NUMBER: builtins.int
    episode_id: builtins.str
    """ID of the episode for which to retrieve manifest URLs."""
    def __init__(
        self,
        *,
        episode_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["episode_id", b"episode_id"]) -> None: ...

global___GetEpisodeManifestsRequest = GetEpisodeManifestsRequest

@typing.final
class GetEpisodeManifestsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANIFESTS_FIELD_NUMBER: builtins.int
    @property
    def manifests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.manifest_pb2.Manifest]:
        """List of manifests available for the episode.
        Different manifests may represent different streaming formats (e.g., HLS, DASH)
        """

    def __init__(
        self,
        *,
        manifests: collections.abc.Iterable[yandex.cloud.video.v1.manifest_pb2.Manifest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["manifests", b"manifests"]) -> None: ...

global___GetEpisodeManifestsResponse = GetEpisodeManifestsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.video.v1.thumbnail_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetThumbnailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail to retrieve.
    Must be a valid thumbnail identifier string.
    """
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___GetThumbnailRequest = GetThumbnailRequest

@typing.final
class ListThumbnailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    EPISODE_ID_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """[Deprecated] ID of the channel."""
    episode_id: builtins.str
    """ID of the episode containing the thumbnails to list."""
    video_id: builtins.str
    """ID of the video containing the thumbnails to list."""
    page_size: builtins.int
    """The maximum number of thumbnails to return per page."""
    page_token: builtins.str
    """Page token for retrieving the next page of results.
    This token is obtained from the next_page_token field in the previous ListThumbnailResponse.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        episode_id: builtins.str = ...,
        video_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["episode_id", b"episode_id", "parent_id", b"parent_id", "video_id", b"video_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "episode_id", b"episode_id", "page_size", b"page_size", "page_token", b"page_token", "parent_id", b"parent_id", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["episode_id", "video_id"] | None: ...

global___ListThumbnailRequest = ListThumbnailRequest

@typing.final
class ListThumbnailResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAILS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for retrieving the next page of results.
    Empty if there are no more results available.
    """
    @property
    def thumbnails(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.thumbnail_pb2.Thumbnail]:
        """List of thumbnails matching the request criteria.
        May be empty if no thumbnails match the criteria or if the parent resource has no thumbnails.
        """

    def __init__(
        self,
        *,
        thumbnails: collections.abc.Iterable[yandex.cloud.video.v1.thumbnail_pb2.Thumbnail] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "thumbnails", b"thumbnails"]) -> None: ...

global___ListThumbnailResponse = ListThumbnailResponse

@typing.final
class CreateThumbnailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    EPISODE_ID_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """[Deprecated] ID of the channel."""
    episode_id: builtins.str
    """ID of the episode to associate the thumbnail with."""
    video_id: builtins.str
    """ID of the video to associate the thumbnail with."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        episode_id: builtins.str = ...,
        video_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["episode_id", b"episode_id", "parent_id", b"parent_id", "video_id", b"video_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "episode_id", b"episode_id", "parent_id", b"parent_id", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parent_id", b"parent_id"]) -> typing.Literal["episode_id", "video_id"] | None: ...

global___CreateThumbnailRequest = CreateThumbnailRequest

@typing.final
class CreateThumbnailMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail being created."""
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___CreateThumbnailMetadata = CreateThumbnailMetadata

@typing.final
class BatchGenerateDownloadURLsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    THUMBNAIL_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel containing the thumbnails."""
    @property
    def thumbnail_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of thumbnail IDs for which to generate download URLs."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        thumbnail_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "thumbnail_ids", b"thumbnail_ids"]) -> None: ...

global___BatchGenerateDownloadURLsRequest = BatchGenerateDownloadURLsRequest

@typing.final
class BatchGenerateDownloadURLsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOAD_URLS_FIELD_NUMBER: builtins.int
    @property
    def download_urls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThumbnailDownloadURL]:
        """List of download URLs for the requested thumbnails.
        Each entry contains URLs for both the original image and various scaled versions.
        """

    def __init__(
        self,
        *,
        download_urls: collections.abc.Iterable[global___ThumbnailDownloadURL] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["download_urls", b"download_urls"]) -> None: ...

global___BatchGenerateDownloadURLsResponse = BatchGenerateDownloadURLsResponse

@typing.final
class ThumbnailDownloadURL(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ImageFormat:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ImageFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ThumbnailDownloadURL._ImageFormat.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IMAGE_FORMAT_UNSPECIFIED: ThumbnailDownloadURL._ImageFormat.ValueType  # 0
        """The image format is not specified."""
        JPEG: ThumbnailDownloadURL._ImageFormat.ValueType  # 1
        """JPEG image format.
        Provides good compression with some quality loss.
        Widely supported across all platforms and browsers.
        """
        WEBP: ThumbnailDownloadURL._ImageFormat.ValueType  # 2
        """WebP image format.
        Provides better compression than JPEG with similar quality.
        May not be supported on all platforms and older browsers.
        """

    class ImageFormat(_ImageFormat, metaclass=_ImageFormatEnumTypeWrapper):
        """Image format of a thumbnail."""

    IMAGE_FORMAT_UNSPECIFIED: ThumbnailDownloadURL.ImageFormat.ValueType  # 0
    """The image format is not specified."""
    JPEG: ThumbnailDownloadURL.ImageFormat.ValueType  # 1
    """JPEG image format.
    Provides good compression with some quality loss.
    Widely supported across all platforms and browsers.
    """
    WEBP: ThumbnailDownloadURL.ImageFormat.ValueType  # 2
    """WebP image format.
    Provides better compression than JPEG with similar quality.
    May not be supported on all platforms and older browsers.
    """

    @typing.final
    class ScaledURL(google.protobuf.message.Message):
        """Represents a URL for a specific scaled version of a thumbnail image."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URL_FIELD_NUMBER: builtins.int
        MAX_WIDTH_FIELD_NUMBER: builtins.int
        MAX_HEIGHT_FIELD_NUMBER: builtins.int
        IMAGE_FORMAT_FIELD_NUMBER: builtins.int
        url: builtins.str
        """URL for downloading this scaled version of the thumbnail."""
        max_width: builtins.int
        """Maximum width in pixels of the scaled image.
        The actual width may be smaller to maintain the aspect ratio.
        """
        max_height: builtins.int
        """Maximum height in pixels of the scaled image.
        The actual height may be smaller to maintain the aspect ratio.
        """
        image_format: global___ThumbnailDownloadURL.ImageFormat.ValueType
        """Format of the scaled image (JPEG, WebP, etc.).
        Different formats offer different trade-offs between quality and file size.
        """
        def __init__(
            self,
            *,
            url: builtins.str = ...,
            max_width: builtins.int = ...,
            max_height: builtins.int = ...,
            image_format: global___ThumbnailDownloadURL.ImageFormat.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["image_format", b"image_format", "max_height", b"max_height", "max_width", b"max_width", "url", b"url"]) -> None: ...

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    ORIGINAL_URL_FIELD_NUMBER: builtins.int
    SCALED_URLS_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail for which download URLs are provided."""
    original_url: builtins.str
    """URL for downloading the original, unmodified thumbnail image.
    This provides access to the image at its original resolution and format.
    """
    @property
    def scaled_urls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThumbnailDownloadURL.ScaledURL]:
        """List of URLs for downloading scaled versions of the thumbnail.
        Different scaled versions are optimized for different display sizes and purposes.
        """

    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
        original_url: builtins.str = ...,
        scaled_urls: collections.abc.Iterable[global___ThumbnailDownloadURL.ScaledURL] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["original_url", b"original_url", "scaled_urls", b"scaled_urls", "thumbnail_id", b"thumbnail_id"]) -> None: ...

global___ThumbnailDownloadURL = ThumbnailDownloadURL

@typing.final
class GenerateThumbnailUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail for which to generate an upload URL.
    The thumbnail record must already exist, typically created using the Create method.
    """
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___GenerateThumbnailUploadURLRequest = GenerateThumbnailUploadURLRequest

@typing.final
class GenerateThumbnailUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Pre-signed URL for uploading the thumbnail image.
    This URL can be used with an HTTP PUT request to upload the image file.
    The URL has a limited validity period and will expire after a certain time.
    """
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["upload_url", b"upload_url"]) -> None: ...

global___GenerateThumbnailUploadURLResponse = GenerateThumbnailUploadURLResponse

@typing.final
class DeleteThumbnailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail to delete."""
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___DeleteThumbnailRequest = DeleteThumbnailRequest

@typing.final
class DeleteThumbnailMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail being deleted.
    This identifier can be used to track the thumbnail deletion operation.
    """
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___DeleteThumbnailMetadata = DeleteThumbnailMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/cache_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/cache_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/cdn/v1/cache_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"E\n\x11PurgeCacheRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\r\n\x05paths\x18\x02 \x03(\t\"7\n\x12PurgeCacheMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"H\n\x14PrefetchCacheRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\r\n\x05paths\x18\x02 \x03(\t\":\n\x15PrefetchCacheMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xfe\x02\n\x0c\x43\x61\x63heService\x12\xaf\x01\n\x05Purge\x12&.yandex.cloud.cdn.v1.PurgeCacheRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*+\n\x12PurgeCacheMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&\"!/cdn/v1/cache/{resource_id}:purge:\x01*\x12\xbb\x01\n\x08Prefetch\x12).yandex.cloud.cdn.v1.PrefetchCacheRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*.\n\x15PrefetchCacheMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)\"$/cdn/v1/cache/{resource_id}:prefetch:\x01*BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.cache_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_PURGECACHEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_PURGECACHEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PURGECACHEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_PURGECACHEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PREFETCHCACHEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_PREFETCHCACHEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PREFETCHCACHEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_PREFETCHCACHEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CACHESERVICE'].methods_by_name['Purge']._loaded_options = None
  _globals['_CACHESERVICE'].methods_by_name['Purge']._serialized_options = b'\262\322*+\n\022PurgeCacheMetadata\022\025google.protobuf.Empty\202\323\344\223\002&\"!/cdn/v1/cache/{resource_id}:purge:\001*'
  _globals['_CACHESERVICE'].methods_by_name['Prefetch']._loaded_options = None
  _globals['_CACHESERVICE'].methods_by_name['Prefetch']._serialized_options = b'\262\322*.\n\025PrefetchCacheMetadata\022\025google.protobuf.Empty\202\323\344\223\002)\"$/cdn/v1/cache/{resource_id}:prefetch:\001*'
  _globals['_PURGECACHEREQUEST']._serialized_start=199
  _globals['_PURGECACHEREQUEST']._serialized_end=268
  _globals['_PURGECACHEMETADATA']._serialized_start=270
  _globals['_PURGECACHEMETADATA']._serialized_end=325
  _globals['_PREFETCHCACHEREQUEST']._serialized_start=327
  _globals['_PREFETCHCACHEREQUEST']._serialized_end=399
  _globals['_PREFETCHCACHEMETADATA']._serialized_start=401
  _globals['_PREFETCHCACHEMETADATA']._serialized_end=459
  _globals['_CACHESERVICE']._serialized_start=462
  _globals['_CACHESERVICE']._serialized_end=844
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/public_subnet.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/public_subnet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.baremetal.v1alpha import dhcp_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_dhcp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/baremetal/v1alpha/public_subnet.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)yandex/cloud/baremetal/v1alpha/dhcp.proto\"\x87\x04\n\x0cPublicSubnet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0f\n\x07zone_id\x18\x07 \x01(\t\x12\x19\n\x11hardware_pool_ids\x18\x08 \x03(\t\x12>\n\x04type\x18\t \x01(\x0e\x32\x30.yandex.cloud.baremetal.v1alpha.PublicSubnetType\x12\x15\n\rprefix_length\x18\n \x01(\x03\x12\x0c\n\x04\x63idr\x18\x0b \x01(\t\x12\x41\n\x0c\x64hcp_options\x18\x0c \x01(\x0b\x32+.yandex.cloud.baremetal.v1alpha.DhcpOptions\x12\x12\n\ngateway_ip\x18\r \x01(\t\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x38.yandex.cloud.baremetal.v1alpha.PublicSubnet.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07J\x04\x08\x0e\x10\x64J\x05\x08\x65\x10\xc8\x01*T\n\x10PublicSubnetType\x12\"\n\x1ePUBLIC_SUBNET_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDEDICATED\x10\x01\x12\r\n\tEPHEMERAL\x10\x02\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.public_subnet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_PUBLICSUBNET_LABELSENTRY']._loaded_options = None
  _globals['_PUBLICSUBNET_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PUBLICSUBNETTYPE']._serialized_start=684
  _globals['_PUBLICSUBNETTYPE']._serialized_end=768
  _globals['_PUBLICSUBNET']._serialized_start=163
  _globals['_PUBLICSUBNET']._serialized_end=682
  _globals['_PUBLICSUBNET_LABELSENTRY']._serialized_start=618
  _globals['_PUBLICSUBNET_LABELSENTRY']._serialized_end=663
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/translate/v2/translation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/translate/v2/translation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ai/translate/v2/translation.proto\x12\x1cyandex.cloud.ai.translate.v2\">\n\x0eTranslatedText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x1e\n\x16\x64\x65tected_language_code\x18\x02 \x01(\t\"&\n\x08Language\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\tBn\n yandex.cloud.api.ai.translate.v2ZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/translate/v2;translateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.translate.v2.translation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.ai.translate.v2ZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/translate/v2;translate'
  _globals['_TRANSLATEDTEXT']._serialized_start=80
  _globals['_TRANSLATEDTEXT']._serialized_end=142
  _globals['_LANGUAGE']._serialized_start=144
  _globals['_LANGUAGE']._serialized_end=182
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RefreshToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ProtectionLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ProtectionLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RefreshToken._ProtectionLevel.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PROTECTION_LEVEL_UNSPECIFIED: RefreshToken._ProtectionLevel.ValueType  # 0
        NO_PROTECTION: RefreshToken._ProtectionLevel.ValueType  # 1
        """Refresh token without DPOP"""
        INSECURE_KEY_DPOP: RefreshToken._ProtectionLevel.ValueType  # 2
        """Refresh token with dpop. The dpop key is not a YubiKey PIV key with required pin/touch policy and attestation."""
        SECURE_KEY_DPOP: RefreshToken._ProtectionLevel.ValueType  # 3
        """Refresh token with dpop. The dpop key is a YubiKey PIV key with required pin/touch policy and attestation."""

    class ProtectionLevel(_ProtectionLevel, metaclass=_ProtectionLevelEnumTypeWrapper):
        """Protection level of the refresh token."""

    PROTECTION_LEVEL_UNSPECIFIED: RefreshToken.ProtectionLevel.ValueType  # 0
    NO_PROTECTION: RefreshToken.ProtectionLevel.ValueType  # 1
    """Refresh token without DPOP"""
    INSECURE_KEY_DPOP: RefreshToken.ProtectionLevel.ValueType  # 2
    """Refresh token with dpop. The dpop key is not a YubiKey PIV key with required pin/touch policy and attestation."""
    SECURE_KEY_DPOP: RefreshToken.ProtectionLevel.ValueType  # 3
    """Refresh token with dpop. The dpop key is a YubiKey PIV key with required pin/touch policy and attestation."""

    ID_FIELD_NUMBER: builtins.int
    CLIENT_INSTANCE_INFO_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    LAST_USED_AT_FIELD_NUMBER: builtins.int
    PROTECTION_LEVEL_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Refresh Token id."""
    client_instance_info: builtins.str
    """Information about the app for which the Refresh Token was issued."""
    client_id: builtins.str
    """The OAuth client identifier for which the Refresh Token was issued."""
    subject_id: builtins.str
    """The subject identifier for whom the Refresh Token was issued."""
    protection_level: global___RefreshToken.ProtectionLevel.ValueType
    """Protection level of the refresh token.

    It shows whether DPOP was used to protect the Refresh Token and and the level of security of the storage used for the DPOP key.
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Refresh token creation time."""

    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Refresh token expiration time."""

    @property
    def last_used_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp for the last authentication using this Refresh Token."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        client_instance_info: builtins.str = ...,
        client_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_used_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        protection_level: global___RefreshToken.ProtectionLevel.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "expires_at", b"expires_at", "last_used_at", b"last_used_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["client_id", b"client_id", "client_instance_info", b"client_instance_info", "created_at", b"created_at", "expires_at", b"expires_at", "id", b"id", "last_used_at", b"last_used_at", "protection_level", b"protection_level", "subject_id", b"subject_id"]) -> None: ...

global___RefreshToken = RefreshToken



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.quotamanager.v1.resource_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class QuotaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QuotaRequest._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: QuotaRequest._Status.ValueType  # 0
        PENDING: QuotaRequest._Status.ValueType  # 1
        """The request is pending and is waiting to be processed."""
        PROCESSING: QuotaRequest._Status.ValueType  # 2
        """The request is processing."""
        PROCESSED: QuotaRequest._Status.ValueType  # 3
        """The request was processed."""
        CANCELED: QuotaRequest._Status.ValueType  # 4
        """The request was canceled."""
        DELETING: QuotaRequest._Status.ValueType  # 5
        """The request is deleting."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: QuotaRequest.Status.ValueType  # 0
    PENDING: QuotaRequest.Status.ValueType  # 1
    """The request is pending and is waiting to be processed."""
    PROCESSING: QuotaRequest.Status.ValueType  # 2
    """The request is processing."""
    PROCESSED: QuotaRequest.Status.ValueType  # 3
    """The request was processed."""
    CANCELED: QuotaRequest.Status.ValueType  # 4
    """The request was canceled."""
    DELETING: QuotaRequest.Status.ValueType  # 5
    """The request is deleting."""

    @typing.final
    class QuotaLimit(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Status:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[QuotaRequest.QuotaLimit._Status.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            STATUS_UNSPECIFIED: QuotaRequest.QuotaLimit._Status.ValueType  # 0
            PENDING: QuotaRequest.QuotaLimit._Status.ValueType  # 1
            """The request is pending and is waiting to be processed."""
            PROCESSING: QuotaRequest.QuotaLimit._Status.ValueType  # 2
            """The request is processing."""
            PARTIAL_APPROVED: QuotaRequest.QuotaLimit._Status.ValueType  # 3
            """The request was partially approved."""
            APPROVED: QuotaRequest.QuotaLimit._Status.ValueType  # 4
            """The request was approved."""
            REJECTED: QuotaRequest.QuotaLimit._Status.ValueType  # 5
            """The request was rejected."""
            CANCELED: QuotaRequest.QuotaLimit._Status.ValueType  # 6
            """The request was canceled."""

        class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
        STATUS_UNSPECIFIED: QuotaRequest.QuotaLimit.Status.ValueType  # 0
        PENDING: QuotaRequest.QuotaLimit.Status.ValueType  # 1
        """The request is pending and is waiting to be processed."""
        PROCESSING: QuotaRequest.QuotaLimit.Status.ValueType  # 2
        """The request is processing."""
        PARTIAL_APPROVED: QuotaRequest.QuotaLimit.Status.ValueType  # 3
        """The request was partially approved."""
        APPROVED: QuotaRequest.QuotaLimit.Status.ValueType  # 4
        """The request was approved."""
        REJECTED: QuotaRequest.QuotaLimit.Status.ValueType  # 5
        """The request was rejected."""
        CANCELED: QuotaRequest.QuotaLimit.Status.ValueType  # 6
        """The request was canceled."""

        QUOTA_ID_FIELD_NUMBER: builtins.int
        DESIRED_LIMIT_FIELD_NUMBER: builtins.int
        APPROVED_LIMIT_FIELD_NUMBER: builtins.int
        UNIT_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        MESSAGE_FIELD_NUMBER: builtins.int
        MODIFIED_BY_FIELD_NUMBER: builtins.int
        quota_id: builtins.str
        """ID of the quota."""
        desired_limit: builtins.float
        """Desired limit."""
        approved_limit: builtins.float
        """Approved limit."""
        unit: builtins.str
        """Unit of quota."""
        status: global___QuotaRequest.QuotaLimit.Status.ValueType
        """Status of current quota limit."""
        message: builtins.str
        modified_by: builtins.str
        """ID of the subject who modified quota limit."""
        def __init__(
            self,
            *,
            quota_id: builtins.str = ...,
            desired_limit: builtins.float = ...,
            approved_limit: builtins.float = ...,
            unit: builtins.str = ...,
            status: global___QuotaRequest.QuotaLimit.Status.ValueType = ...,
            message: builtins.str = ...,
            modified_by: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["approved_limit", b"approved_limit", "desired_limit", b"desired_limit", "message", b"message", "modified_by", b"modified_by", "quota_id", b"quota_id", "status", b"status", "unit", b"unit"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    QUOTA_LIMITS_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the quota request."""
    status: global___QuotaRequest.Status.ValueType
    """Status of current quota request."""
    created_by: builtins.str
    """ID of the subject who created quota request."""
    @property
    def resource(self) -> yandex.cloud.quotamanager.v1.resource_pb2.Resource: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def quota_limits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QuotaRequest.QuotaLimit]:
        """Quota limits"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        resource: yandex.cloud.quotamanager.v1.resource_pb2.Resource | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___QuotaRequest.Status.ValueType = ...,
        quota_limits: collections.abc.Iterable[global___QuotaRequest.QuotaLimit] | None = ...,
        created_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "created_by", b"created_by", "id", b"id", "quota_limits", b"quota_limits", "resource", b"resource", "status", b"status"]) -> None: ...

global___QuotaRequest = QuotaRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.clouddesktop.v1.desktop_group_pb2
import yandex.cloud.clouddesktop.v1.desktop_group_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DesktopGroupServiceStub:
    """A set of methods for managing desktop group resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.GetDesktopGroupRequest,
        yandex.cloud.clouddesktop.v1.desktop_group_pb2.DesktopGroup,
    ]
    """Returns the specified desktop group resource.

    To get the list of available desktop groups, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupsRequest,
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupsResponse,
    ]
    """Retrieves the list of desktop group resources."""

    ListDesktops: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupDesktopsRequest,
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupDesktopsResponse,
    ]
    """Retrieves the list of desktops resources."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupOperationsRequest,
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupOperationsResponse,
    ]
    """Returns list of the operations for the specified desktop group."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.CreateDesktopGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates desktop group in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.UpdateDesktopGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates desktop group properties"""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.DeleteDesktopGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified desktop group."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Returns a list of the access bindings for the specified desktop group."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified desktop group."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings of the specified desktop group."""

class DesktopGroupServiceAsyncStub:
    """A set of methods for managing desktop group resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.GetDesktopGroupRequest,
        yandex.cloud.clouddesktop.v1.desktop_group_pb2.DesktopGroup,
    ]
    """Returns the specified desktop group resource.

    To get the list of available desktop groups, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupsRequest,
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupsResponse,
    ]
    """Retrieves the list of desktop group resources."""

    ListDesktops: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupDesktopsRequest,
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupDesktopsResponse,
    ]
    """Retrieves the list of desktops resources."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupOperationsRequest,
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupOperationsResponse,
    ]
    """Returns list of the operations for the specified desktop group."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.CreateDesktopGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates desktop group in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.UpdateDesktopGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates desktop group properties"""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.DeleteDesktopGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified desktop group."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Returns a list of the access bindings for the specified desktop group."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified desktop group."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings of the specified desktop group."""

class DesktopGroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing desktop group resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.GetDesktopGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_group_pb2.DesktopGroup, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_group_pb2.DesktopGroup]]:
        """Returns the specified desktop group resource.

        To get the list of available desktop groups, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupsResponse, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupsResponse]]:
        """Retrieves the list of desktop group resources."""

    @abc.abstractmethod
    def ListDesktops(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupDesktopsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupDesktopsResponse, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupDesktopsResponse]]:
        """Retrieves the list of desktops resources."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.ListDesktopGroupOperationsResponse]]:
        """Returns list of the operations for the specified desktop group."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.CreateDesktopGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates desktop group in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.UpdateDesktopGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates desktop group properties"""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.clouddesktop.v1.desktop_group_service_pb2.DeleteDesktopGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified desktop group."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Returns a list of the access bindings for the specified desktop group."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified desktop group."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings of the specified desktop group."""

def add_DesktopGroupServiceServicer_to_server(servicer: DesktopGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FormatSchemaType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FormatSchemaTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FormatSchemaType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FORMAT_SCHEMA_TYPE_UNSPECIFIED: _FormatSchemaType.ValueType  # 0
    FORMAT_SCHEMA_TYPE_PROTOBUF: _FormatSchemaType.ValueType  # 1
    FORMAT_SCHEMA_TYPE_CAPNPROTO: _FormatSchemaType.ValueType  # 2

class FormatSchemaType(_FormatSchemaType, metaclass=_FormatSchemaTypeEnumTypeWrapper): ...

FORMAT_SCHEMA_TYPE_UNSPECIFIED: FormatSchemaType.ValueType  # 0
FORMAT_SCHEMA_TYPE_PROTOBUF: FormatSchemaType.ValueType  # 1
FORMAT_SCHEMA_TYPE_CAPNPROTO: FormatSchemaType.ValueType  # 2
global___FormatSchemaType = FormatSchemaType

@typing.final
class FormatSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Format schema name."""
    cluster_id: builtins.str
    """ClickHouse cluster ID."""
    type: global___FormatSchemaType.ValueType
    """Schema type. Possible values are the following:

    * FORMAT_SCHEMA_TYPE_PROTOBUF - [Protobuf](https://protobuf.dev/) data format (including [ProtobufSingle](https://clickhouse.com/docs/en/interfaces/formats#protobufsingle)).
    * FORMAT_SCHEMA_TYPE_CAPNPROTO - [Cap'n Proto](https://capnproto.org/) data format.
    """
    uri: builtins.str
    """Link to the file of a format schema in Yandex Object Storage. Managed Service for ClickHouse works only with format schemas imported to Object Storage."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        type: global___FormatSchemaType.ValueType = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "type", b"type", "uri", b"uri"]) -> None: ...

global___FormatSchema = FormatSchema
